@@ -856,27 +856,8 @@ class TestClockSyncUtils(ironic_agent_base.IronicAgentTest):
         mock_time_method.return_value = 'chronyd'
         utils.sync_clock()
         mock_execute.assert_has_calls([
-            mock.call('chronyd', check_exit_code=[0, 1]),
-            mock.call('chronyc', 'add', 'server', '192.168.1.1'),
-            mock.call('chronyc', 'makestep'),
-        ])
-
-    @mock.patch.object(utils, 'determine_time_method', autospec=True)
-    def test_sync_clock_chrony_already_present(self, mock_time_method,
-                                               mock_execute):
-        self.config(ntp_server='192.168.1.1')
-        mock_time_method.return_value = 'chronyd'
-        mock_execute.side_effect = [
-            ('', ''),
-            processutils.ProcessExecutionError(
-                stderr='Source already present'),
-            ('', ''),
-        ]
-        utils.sync_clock()
-        mock_execute.assert_has_calls([
-            mock.call('chronyd', check_exit_code=[0, 1]),
-            mock.call('chronyc', 'add', 'server', '192.168.1.1'),
-            mock.call('chronyc', 'makestep'),
+            mock.call('chronyc', 'shutdown', check_exit_code=[0, 1]),
+            mock.call("chronyd -q 'server 192.168.1.1 iburst'", shell=True),
         ])
 
     @mock.patch.object(utils, 'determine_time_method', autospec=True)
@@ -889,12 +870,8 @@ class TestClockSyncUtils(ironic_agent_base.IronicAgentTest):
             processutils.ProcessExecutionError(stderr='time verboten'),
         ]
         self.assertRaisesRegex(errors.CommandExecutionError,
-                               'Error occured adding ntp',
-                               utils.sync_clock)
-        mock_execute.assert_has_calls([
-            mock.call('chronyd', check_exit_code=[0, 1]),
-            mock.call('chronyc', 'add', 'server', '192.168.1.1'),
-        ])
+                               'Failed to sync time using chrony to ntp '
+                               'server:', utils.sync_clock)
 
     @mock.patch.object(utils, 'determine_time_method', autospec=True)
     def test_sync_clock_none(self, mock_time_method, mock_execute):
@@ -1197,3 +1174,26 @@ class TestCheckVirtualMedia(ironic_agent_base.IronicAgentTest):
         mock_execute.assert_called_with('lsblk', '-n', '-s', '-P', '-b',
                                         '-oKNAME,TRAN,TYPE,SIZE',
                                         '/dev/sdh')
+
+
+class TestCheckEarlyLogging(ironic_agent_base.IronicAgentTest):
+
+    @mock.patch.object(utils, 'LOG', autospec=True)
+    def test_early_logging_goes_to_logger(self, mock_log):
+        info = mock.Mock()
+        mock_log.info.side_effect = info
+        # Reset the buffer to be empty.
+        utils._EARLY_LOG_BUFFER = []
+        # Store some data via _early_log
+        utils._early_log('line 1.')
+        utils._early_log('line 2 %s', 'message')
+        expected_messages = ['line 1.',
+                             'line 2 message']
+        self.assertEqual(expected_messages, utils._EARLY_LOG_BUFFER)
+        # Test we've got data in the buffer.
+        info.assert_not_called()
+        # Test the other half of this.
+        utils.log_early_log_to_logger()
+        expected_calls = [mock.call('Early logging: %s', 'line 1.'),
+                          mock.call('Early logging: %s', 'line 2 message')]
+        info.assert_has_calls(expected_calls)
